# Myfxbook API

I made a simple class to make it easier to use Myfxbook

To get to know its functions and parameters, you can find out from the official website [Myfxbook API](https://www.myfxbook.com/api)

## How to use

``` python
import myfxbook

fx = myfxbook.myfxbook('<Username>', '<Password>')
fx.login()
print(fxbook.get_watched_accounts())
fx.logout()
```
